@@ -1,5 +1,5 @@
 package Data::Perl::Role::Collection::Array;
-$Data::Perl::Role::Collection::Array::VERSION = '0.002008';
+$Data::Perl::Role::Collection::Array::VERSION = '0.002010';
 # ABSTRACT: Wrapping class for Perl's built in array structure.
 
 use strictures 1;
@@ -186,6 +186,29 @@ sub print {
   print { $fh || *STDOUT } CORE::join((defined $arg ? $arg : ','), @$self);
 }
 
+sub head {
+  my ($self, $count) = @_;
+
+  $count = $self->count if $count > $self->count;
+  $count = $self->count - -$count if $count < 0;
+
+  my @res = ($self->elements)[0 .. $count - 1];
+
+  blessed($self) ? blessed($self)->new(@res) : @res;
+}
+
+sub tail {
+  my ($self, $count) = @_;
+
+  $count = $self->count if $count > $self->count;
+  $count = $self->count - -$count if $count < 0;
+  my $start = $self->count - $count;
+
+  my @res = ($self->elements)[$start .. $self->count - 1];
+
+  blessed($self) ? blessed($self)->new(@res) : @res;
+}
+
 1;
 
 =pod
@@ -198,7 +221,7 @@ Data::Perl::Role::Collection::Array - Wrapping class for Perl's built in array s
 
 =head1 VERSION
 
-version 0.002008
+version 0.002010
 
 =head1 SYNOPSIS
 
@@ -224,7 +247,7 @@ All methods that return a list do so via a Data::Perl::Collection::Array object.
 Constructs a new Data::Perl::Collection::Array object initialized with passed
 in values, and returns it.
 
-=item * B<count>
+=item B<count>
 
 Returns the number of elements in the array.
 
@@ -234,7 +257,7 @@ Returns the number of elements in the array.
 
 This method does not accept any arguments.
 
-=item * B<is_empty>
+=item B<is_empty>
 
 Returns a boolean value that is true when the array has no elements.
 
@@ -242,7 +265,7 @@ Returns a boolean value that is true when the array has no elements.
 
 This method does not accept any arguments.
 
-=item * B<elements/all>
+=item B<elements/all>
 
 Returns all of the elements of the array as an array (not an array reference).
 
@@ -251,7 +274,7 @@ Returns all of the elements of the array as an array (not an array reference).
 
 This method does not accept any arguments.
 
-=item * B<get($index)>
+=item B<get($index)>
 
 Returns an element of the array by its index. You can also use negative index
 numbers, just as with Perl's core array handling.
@@ -263,33 +286,33 @@ If the specified element does not exist, this will return C<undef>.
 
 This method accepts just one argument.
 
-=item * B<pop>
+=item B<pop>
 
 Just like Perl's builtin C<pop>.
 
 This method does not accept any arguments.
 
-=item * B<push($value1, $value2, value3 ...)>
+=item B<push($value1, $value2, value3 ...)>
 
 Just like Perl's builtin C<push>. Returns the number of elements in the new
 array.
 
 This method accepts any number of arguments.
 
-=item * B<shift>
+=item B<shift>
 
 Just like Perl's builtin C<shift>.
 
 This method does not accept any arguments.
 
-=item * B<unshift($value1, $value2, value3 ...)>
+=item B<unshift($value1, $value2, value3 ...)>
 
 Just like Perl's builtin C<unshift>. Returns the number of elements in the new
 array.
 
 This method accepts any number of arguments.
 
-=item * B<splice($offset, $length, @values)>
+=item B<splice($offset, $length, @values)>
 
 Just like Perl's builtin C<splice>. In scalar context, this returns the last
 element removed, or C<undef> if no elements were removed. In list context, this
@@ -298,7 +321,7 @@ object.
 
 This method requires at least one argument.
 
-=item * B<first( sub { ... } )>
+=item B<first( sub { ... } )>
 
 This method returns the first matching item in the array, just like
 L<List::Util>'s C<first> function. The matching is done with a subroutine
@@ -310,7 +333,7 @@ element in the array until one matches or all elements have been checked.
 
 This method requires a single argument.
 
-=item * B<first_index( sub { ... } )>
+=item B<first_index( sub { ... } )>
 
 This method returns the index of the first matching item in the array, just
 like L<List::MoreUtils>'s C<first_index> function. The matching is done with a
@@ -320,7 +343,7 @@ checked.
 
 This method requires a single argument.
 
-=item * B<grep( sub { ... } )>
+=item B<grep( sub { ... } )>
 
 This method returns every element matching a given criteria, just like Perl's
 core C<grep> function. This method requires a subroutine which implements the
@@ -331,7 +354,7 @@ matching logic. The returned list is provided as a Collection::Array object.
 
 This method requires a single argument.
 
-=item * B<map( sub { ... } )>
+=item B<map( sub { ... } )>
 
 This method transforms every element in the array and returns a new array, just
 like Perl's core C<map> function. This method requires a subroutine which
@@ -343,7 +366,7 @@ a Collection::Array object.
 
 This method requires a single argument.
 
-=item * B<reduce( sub { ... } )>
+=item B<reduce( sub { ... } )>
 
 This method turns an array into a single value, by passing a function the
 value so far and the next value in the array, just like L<List::Util>'s
@@ -355,9 +378,9 @@ to this method.
 
 This method requires a single argument.
 
-=item * B<sort>
+=item B<sort>
 
-=item * B<sort( sub { ... } )>
+=item B<sort( sub { ... } )>
 
 Returns the elements of the array in sorted order.
 
@@ -375,9 +398,9 @@ is provided as a Collection::Array object.
 
 This method accepts a single argument.
 
-=item * B<sort_in_place>
+=item B<sort_in_place>
 
-=item * B<sort_in_place( sub { ... } )>
+=item B<sort_in_place( sub { ... } )>
 
 Sorts the array I<in place>, modifying the value of the attribute.
 
@@ -388,28 +411,42 @@ as a Collection::Array object.
 
 This method accepts a single argument.
 
-=item * B<reverse>
+=item B<reverse>
 
 Returns the elements of the array in reversed order. The returned list is
 provided as a Collection::Array object.
 
 This method does not accept any arguments.
 
-=item * B<shuffle>
+=item B<shuffle>
 
 Returns the elements of the array in random order, like C<shuffle> from
 L<List::Util>. The returned list is provided as a Collection::Array object.
 
 This method does not accept any arguments.
 
-=item * B<uniq>
+=item B<uniq>
 
 Returns the array with all duplicate elements removed, like C<uniq> from
 L<List::MoreUtils>. The returned list is provided as a Collection::Array object.
 
 This method does not accept any arguments.
 
-=item * B<join($str)>
+=item B<head($count)>
+
+Returns the first C<$count> elements of the array. If C<$count> is greater
+than the number of elements in the array, the array (without spurious C<undef>s)
+is returned. Negative C<$count> means "all but the last C<$count> elements". The
+returned list is provided as a Collection::Array object.
+
+=item B<tail($count)>
+
+Returns the last C<$count> elements of the array. If C<$count> is greater
+than the number of elements in the array, the array (without spurious C<undef>s)
+is returned. Negative C<$count> means "all but the first C<$count> elements". The
+returned list is provided as a Collection::Array object.
+
+=item B<join($str)>
 
 Joins every element of the array using the separator given as argument, just
 like Perl's core C<join> function.
@@ -419,14 +456,14 @@ like Perl's core C<join> function.
 
 This method requires a single argument.
 
-=item * B<print($handle, $str)>
+=item B<print($handle, $str)>
 
 Prints the output of join($str) to $handle. $handle defaults to STDOUT, and
 join $str defaults to join()'s default of ','.
 
   $joined = $stuff->print(*STDERR, ';'); # prints foo;bar;baz to STDERR
 
-=item * B<set($index, $value)>
+=item B<set($index, $value)>
 
 Given an index and a value, sets the specified array element's value.
 
@@ -434,7 +471,7 @@ This method returns the value at C<$index> after the set.
 
 This method requires two arguments.
 
-=item * B<delete($index)>
+=item B<delete($index)>
 
 Removes the element at the given index from the array.
 
@@ -445,7 +482,7 @@ return C<undef>.
 
 This method requires one argument.
 
-=item * B<insert($index, $value)>
+=item B<insert($index, $value)>
 
 Inserts a new element into the array at the given index.
 
@@ -454,7 +491,7 @@ dependent on splice context semantics.
 
 This method requires two arguments.
 
-=item * B<clear>
+=item B<clear>
 
 Empties the entire array, like C<@array = ()>.
 
@@ -462,9 +499,9 @@ This method does not define a return value.
 
 This method does not accept any arguments.
 
-=item * B<accessor($index)>
+=item B<accessor($index)>
 
-=item * B<accessor($index, $value)>
+=item B<accessor($index, $value)>
 
 This method provides a get/set accessor for the array, based on array indexes.
 If passed one argument, it returns the value at the specified index.  If
@@ -474,9 +511,9 @@ When called as a setter, this method returns the new value at C<$index>.
 
 This method accepts one or two arguments.
 
-=item * B<natatime($n)>
+=item B<natatime($n)>
 
-=item * B<natatime($n, $code)>
+=item B<natatime($n, $code)>
 
 This method returns an iterator which, on each call, returns C<$n> more items
 from the array, in order, like C<natatime> from L<List::MoreUtils>. A coderef
@@ -485,19 +522,19 @@ in the array.
 
 This method accepts one or two arguments.
 
-=item * B<shallow_clone>
+=item B<shallow_clone>
 
 This method returns a shallow clone of the array reference.  The return value
 is a reference to a new array with the same elements.  It is I<shallow>
 because any elements that were references in the original will be the I<same>
 references in the clone.
 
-=item * B<flatten>
+=item B<flatten>
 
 This method returns a list of elements in the array.  This method is an alias
 to the I<elements> method.
 
-=item * B<flatten_deep($level)>
+=item B<flatten_deep($level)>
 
 This method returns a flattened list of elements in the array. Will flatten
 arrays contained within the root array recursively - depth is controlled by the
@@ -521,7 +558,7 @@ Matthew Phillips <mattp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Matthew Phillips <mattp@cpan.org>.
+This software is copyright (c) 2020 by Matthew Phillips <mattp@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
